# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from emby_client.api_client import ApiClient


class DlnaServerServiceApi(object):
    """NOTE: This class is auto generated.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_dlna_by_uuid_connectionmanager_connectionmanager(self, uu_id, **kwargs):  # noqa: E501
        """Gets dlna connection manager xml  # noqa: E501

        No authentication required  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_dlna_by_uuid_connectionmanager_connectionmanager(uu_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str uu_id: Server UuId (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_dlna_by_uuid_connectionmanager_connectionmanager_with_http_info(uu_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_dlna_by_uuid_connectionmanager_connectionmanager_with_http_info(uu_id, **kwargs)  # noqa: E501
            return data

    def get_dlna_by_uuid_connectionmanager_connectionmanager_with_http_info(self, uu_id, **kwargs):  # noqa: E501
        """Gets dlna connection manager xml  # noqa: E501

        No authentication required  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_dlna_by_uuid_connectionmanager_connectionmanager_with_http_info(uu_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str uu_id: Server UuId (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['uu_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_dlna_by_uuid_connectionmanager_connectionmanager" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'uu_id' is set
        if ('uu_id' not in params or
                params['uu_id'] is None):
            raise ValueError("Missing the required parameter `uu_id` when calling `get_dlna_by_uuid_connectionmanager_connectionmanager`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'uu_id' in params:
            path_params['UuId'] = params['uu_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/Dlna/{UuId}/connectionmanager/connectionmanager', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_dlna_by_uuid_connectionmanager_connectionmanager_xml(self, uu_id, **kwargs):  # noqa: E501
        """Gets dlna connection manager xml  # noqa: E501

        No authentication required  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_dlna_by_uuid_connectionmanager_connectionmanager_xml(uu_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str uu_id: Server UuId (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_dlna_by_uuid_connectionmanager_connectionmanager_xml_with_http_info(uu_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_dlna_by_uuid_connectionmanager_connectionmanager_xml_with_http_info(uu_id, **kwargs)  # noqa: E501
            return data

    def get_dlna_by_uuid_connectionmanager_connectionmanager_xml_with_http_info(self, uu_id, **kwargs):  # noqa: E501
        """Gets dlna connection manager xml  # noqa: E501

        No authentication required  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_dlna_by_uuid_connectionmanager_connectionmanager_xml_with_http_info(uu_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str uu_id: Server UuId (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['uu_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_dlna_by_uuid_connectionmanager_connectionmanager_xml" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'uu_id' is set
        if ('uu_id' not in params or
                params['uu_id'] is None):
            raise ValueError("Missing the required parameter `uu_id` when calling `get_dlna_by_uuid_connectionmanager_connectionmanager_xml`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'uu_id' in params:
            path_params['UuId'] = params['uu_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/Dlna/{UuId}/connectionmanager/connectionmanager.xml', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_dlna_by_uuid_contentdirectory_contentdirectory(self, uu_id, **kwargs):  # noqa: E501
        """Gets dlna content directory xml  # noqa: E501

        No authentication required  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_dlna_by_uuid_contentdirectory_contentdirectory(uu_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str uu_id: Server UuId (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_dlna_by_uuid_contentdirectory_contentdirectory_with_http_info(uu_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_dlna_by_uuid_contentdirectory_contentdirectory_with_http_info(uu_id, **kwargs)  # noqa: E501
            return data

    def get_dlna_by_uuid_contentdirectory_contentdirectory_with_http_info(self, uu_id, **kwargs):  # noqa: E501
        """Gets dlna content directory xml  # noqa: E501

        No authentication required  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_dlna_by_uuid_contentdirectory_contentdirectory_with_http_info(uu_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str uu_id: Server UuId (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['uu_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_dlna_by_uuid_contentdirectory_contentdirectory" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'uu_id' is set
        if ('uu_id' not in params or
                params['uu_id'] is None):
            raise ValueError("Missing the required parameter `uu_id` when calling `get_dlna_by_uuid_contentdirectory_contentdirectory`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'uu_id' in params:
            path_params['UuId'] = params['uu_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/Dlna/{UuId}/contentdirectory/contentdirectory', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_dlna_by_uuid_contentdirectory_contentdirectory_xml(self, uu_id, **kwargs):  # noqa: E501
        """Gets dlna content directory xml  # noqa: E501

        No authentication required  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_dlna_by_uuid_contentdirectory_contentdirectory_xml(uu_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str uu_id: Server UuId (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_dlna_by_uuid_contentdirectory_contentdirectory_xml_with_http_info(uu_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_dlna_by_uuid_contentdirectory_contentdirectory_xml_with_http_info(uu_id, **kwargs)  # noqa: E501
            return data

    def get_dlna_by_uuid_contentdirectory_contentdirectory_xml_with_http_info(self, uu_id, **kwargs):  # noqa: E501
        """Gets dlna content directory xml  # noqa: E501

        No authentication required  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_dlna_by_uuid_contentdirectory_contentdirectory_xml_with_http_info(uu_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str uu_id: Server UuId (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['uu_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_dlna_by_uuid_contentdirectory_contentdirectory_xml" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'uu_id' is set
        if ('uu_id' not in params or
                params['uu_id'] is None):
            raise ValueError("Missing the required parameter `uu_id` when calling `get_dlna_by_uuid_contentdirectory_contentdirectory_xml`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'uu_id' in params:
            path_params['UuId'] = params['uu_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/Dlna/{UuId}/contentdirectory/contentdirectory.xml', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_dlna_by_uuid_description(self, uu_id, **kwargs):  # noqa: E501
        """Gets dlna server info  # noqa: E501

        No authentication required  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_dlna_by_uuid_description(uu_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str uu_id: Server UuId (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_dlna_by_uuid_description_with_http_info(uu_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_dlna_by_uuid_description_with_http_info(uu_id, **kwargs)  # noqa: E501
            return data

    def get_dlna_by_uuid_description_with_http_info(self, uu_id, **kwargs):  # noqa: E501
        """Gets dlna server info  # noqa: E501

        No authentication required  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_dlna_by_uuid_description_with_http_info(uu_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str uu_id: Server UuId (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['uu_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_dlna_by_uuid_description" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'uu_id' is set
        if ('uu_id' not in params or
                params['uu_id'] is None):
            raise ValueError("Missing the required parameter `uu_id` when calling `get_dlna_by_uuid_description`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'uu_id' in params:
            path_params['UuId'] = params['uu_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/Dlna/{UuId}/description', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_dlna_by_uuid_description_xml(self, uu_id, **kwargs):  # noqa: E501
        """Gets dlna server info  # noqa: E501

        No authentication required  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_dlna_by_uuid_description_xml(uu_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str uu_id: Server UuId (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_dlna_by_uuid_description_xml_with_http_info(uu_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_dlna_by_uuid_description_xml_with_http_info(uu_id, **kwargs)  # noqa: E501
            return data

    def get_dlna_by_uuid_description_xml_with_http_info(self, uu_id, **kwargs):  # noqa: E501
        """Gets dlna server info  # noqa: E501

        No authentication required  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_dlna_by_uuid_description_xml_with_http_info(uu_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str uu_id: Server UuId (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['uu_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_dlna_by_uuid_description_xml" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'uu_id' is set
        if ('uu_id' not in params or
                params['uu_id'] is None):
            raise ValueError("Missing the required parameter `uu_id` when calling `get_dlna_by_uuid_description_xml`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'uu_id' in params:
            path_params['UuId'] = params['uu_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/Dlna/{UuId}/description.xml', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_dlna_by_uuid_icons_by_filename(self, uu_id, filename, **kwargs):  # noqa: E501
        """Gets a server icon  # noqa: E501

        No authentication required  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_dlna_by_uuid_icons_by_filename(uu_id, filename, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str uu_id: Server UuId (required)
        :param str filename: The icon filename (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_dlna_by_uuid_icons_by_filename_with_http_info(uu_id, filename, **kwargs)  # noqa: E501
        else:
            (data) = self.get_dlna_by_uuid_icons_by_filename_with_http_info(uu_id, filename, **kwargs)  # noqa: E501
            return data

    def get_dlna_by_uuid_icons_by_filename_with_http_info(self, uu_id, filename, **kwargs):  # noqa: E501
        """Gets a server icon  # noqa: E501

        No authentication required  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_dlna_by_uuid_icons_by_filename_with_http_info(uu_id, filename, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str uu_id: Server UuId (required)
        :param str filename: The icon filename (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['uu_id', 'filename']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_dlna_by_uuid_icons_by_filename" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'uu_id' is set
        if ('uu_id' not in params or
                params['uu_id'] is None):
            raise ValueError("Missing the required parameter `uu_id` when calling `get_dlna_by_uuid_icons_by_filename`")  # noqa: E501
        # verify the required parameter 'filename' is set
        if ('filename' not in params or
                params['filename'] is None):
            raise ValueError("Missing the required parameter `filename` when calling `get_dlna_by_uuid_icons_by_filename`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'uu_id' in params:
            path_params['UuId'] = params['uu_id']  # noqa: E501
        if 'filename' in params:
            path_params['Filename'] = params['filename']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/Dlna/{UuId}/icons/{Filename}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_dlna_icons_by_filename(self, filename, **kwargs):  # noqa: E501
        """Gets a server icon  # noqa: E501

        No authentication required  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_dlna_icons_by_filename(filename, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str filename: The icon filename (required)
        :param str uu_id: Server UuId
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_dlna_icons_by_filename_with_http_info(filename, **kwargs)  # noqa: E501
        else:
            (data) = self.get_dlna_icons_by_filename_with_http_info(filename, **kwargs)  # noqa: E501
            return data

    def get_dlna_icons_by_filename_with_http_info(self, filename, **kwargs):  # noqa: E501
        """Gets a server icon  # noqa: E501

        No authentication required  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_dlna_icons_by_filename_with_http_info(filename, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str filename: The icon filename (required)
        :param str uu_id: Server UuId
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['filename', 'uu_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_dlna_icons_by_filename" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'filename' is set
        if ('filename' not in params or
                params['filename'] is None):
            raise ValueError("Missing the required parameter `filename` when calling `get_dlna_icons_by_filename`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'filename' in params:
            path_params['Filename'] = params['filename']  # noqa: E501

        query_params = []
        if 'uu_id' in params:
            query_params.append(('UuId', params['uu_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/Dlna/icons/{Filename}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def head_dlna_by_uuid_connectionmanager_connectionmanager(self, uu_id, **kwargs):  # noqa: E501
        """Gets dlna connection manager xml  # noqa: E501

        No authentication required  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.head_dlna_by_uuid_connectionmanager_connectionmanager(uu_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str uu_id: Server UuId (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.head_dlna_by_uuid_connectionmanager_connectionmanager_with_http_info(uu_id, **kwargs)  # noqa: E501
        else:
            (data) = self.head_dlna_by_uuid_connectionmanager_connectionmanager_with_http_info(uu_id, **kwargs)  # noqa: E501
            return data

    def head_dlna_by_uuid_connectionmanager_connectionmanager_with_http_info(self, uu_id, **kwargs):  # noqa: E501
        """Gets dlna connection manager xml  # noqa: E501

        No authentication required  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.head_dlna_by_uuid_connectionmanager_connectionmanager_with_http_info(uu_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str uu_id: Server UuId (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['uu_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method head_dlna_by_uuid_connectionmanager_connectionmanager" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'uu_id' is set
        if ('uu_id' not in params or
                params['uu_id'] is None):
            raise ValueError("Missing the required parameter `uu_id` when calling `head_dlna_by_uuid_connectionmanager_connectionmanager`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'uu_id' in params:
            path_params['UuId'] = params['uu_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/Dlna/{UuId}/connectionmanager/connectionmanager', 'HEAD',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def head_dlna_by_uuid_connectionmanager_connectionmanager_xml(self, uu_id, **kwargs):  # noqa: E501
        """Gets dlna connection manager xml  # noqa: E501

        No authentication required  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.head_dlna_by_uuid_connectionmanager_connectionmanager_xml(uu_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str uu_id: Server UuId (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.head_dlna_by_uuid_connectionmanager_connectionmanager_xml_with_http_info(uu_id, **kwargs)  # noqa: E501
        else:
            (data) = self.head_dlna_by_uuid_connectionmanager_connectionmanager_xml_with_http_info(uu_id, **kwargs)  # noqa: E501
            return data

    def head_dlna_by_uuid_connectionmanager_connectionmanager_xml_with_http_info(self, uu_id, **kwargs):  # noqa: E501
        """Gets dlna connection manager xml  # noqa: E501

        No authentication required  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.head_dlna_by_uuid_connectionmanager_connectionmanager_xml_with_http_info(uu_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str uu_id: Server UuId (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['uu_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method head_dlna_by_uuid_connectionmanager_connectionmanager_xml" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'uu_id' is set
        if ('uu_id' not in params or
                params['uu_id'] is None):
            raise ValueError("Missing the required parameter `uu_id` when calling `head_dlna_by_uuid_connectionmanager_connectionmanager_xml`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'uu_id' in params:
            path_params['UuId'] = params['uu_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/Dlna/{UuId}/connectionmanager/connectionmanager.xml', 'HEAD',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def head_dlna_by_uuid_contentdirectory_contentdirectory(self, uu_id, **kwargs):  # noqa: E501
        """Gets dlna content directory xml  # noqa: E501

        No authentication required  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.head_dlna_by_uuid_contentdirectory_contentdirectory(uu_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str uu_id: Server UuId (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.head_dlna_by_uuid_contentdirectory_contentdirectory_with_http_info(uu_id, **kwargs)  # noqa: E501
        else:
            (data) = self.head_dlna_by_uuid_contentdirectory_contentdirectory_with_http_info(uu_id, **kwargs)  # noqa: E501
            return data

    def head_dlna_by_uuid_contentdirectory_contentdirectory_with_http_info(self, uu_id, **kwargs):  # noqa: E501
        """Gets dlna content directory xml  # noqa: E501

        No authentication required  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.head_dlna_by_uuid_contentdirectory_contentdirectory_with_http_info(uu_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str uu_id: Server UuId (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['uu_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method head_dlna_by_uuid_contentdirectory_contentdirectory" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'uu_id' is set
        if ('uu_id' not in params or
                params['uu_id'] is None):
            raise ValueError("Missing the required parameter `uu_id` when calling `head_dlna_by_uuid_contentdirectory_contentdirectory`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'uu_id' in params:
            path_params['UuId'] = params['uu_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/Dlna/{UuId}/contentdirectory/contentdirectory', 'HEAD',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def head_dlna_by_uuid_contentdirectory_contentdirectory_xml(self, uu_id, **kwargs):  # noqa: E501
        """Gets dlna content directory xml  # noqa: E501

        No authentication required  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.head_dlna_by_uuid_contentdirectory_contentdirectory_xml(uu_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str uu_id: Server UuId (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.head_dlna_by_uuid_contentdirectory_contentdirectory_xml_with_http_info(uu_id, **kwargs)  # noqa: E501
        else:
            (data) = self.head_dlna_by_uuid_contentdirectory_contentdirectory_xml_with_http_info(uu_id, **kwargs)  # noqa: E501
            return data

    def head_dlna_by_uuid_contentdirectory_contentdirectory_xml_with_http_info(self, uu_id, **kwargs):  # noqa: E501
        """Gets dlna content directory xml  # noqa: E501

        No authentication required  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.head_dlna_by_uuid_contentdirectory_contentdirectory_xml_with_http_info(uu_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str uu_id: Server UuId (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['uu_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method head_dlna_by_uuid_contentdirectory_contentdirectory_xml" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'uu_id' is set
        if ('uu_id' not in params or
                params['uu_id'] is None):
            raise ValueError("Missing the required parameter `uu_id` when calling `head_dlna_by_uuid_contentdirectory_contentdirectory_xml`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'uu_id' in params:
            path_params['UuId'] = params['uu_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/Dlna/{UuId}/contentdirectory/contentdirectory.xml', 'HEAD',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def head_dlna_by_uuid_description(self, uu_id, **kwargs):  # noqa: E501
        """Gets dlna server info  # noqa: E501

        No authentication required  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.head_dlna_by_uuid_description(uu_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str uu_id: Server UuId (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.head_dlna_by_uuid_description_with_http_info(uu_id, **kwargs)  # noqa: E501
        else:
            (data) = self.head_dlna_by_uuid_description_with_http_info(uu_id, **kwargs)  # noqa: E501
            return data

    def head_dlna_by_uuid_description_with_http_info(self, uu_id, **kwargs):  # noqa: E501
        """Gets dlna server info  # noqa: E501

        No authentication required  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.head_dlna_by_uuid_description_with_http_info(uu_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str uu_id: Server UuId (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['uu_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method head_dlna_by_uuid_description" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'uu_id' is set
        if ('uu_id' not in params or
                params['uu_id'] is None):
            raise ValueError("Missing the required parameter `uu_id` when calling `head_dlna_by_uuid_description`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'uu_id' in params:
            path_params['UuId'] = params['uu_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/Dlna/{UuId}/description', 'HEAD',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def head_dlna_by_uuid_description_xml(self, uu_id, **kwargs):  # noqa: E501
        """Gets dlna server info  # noqa: E501

        No authentication required  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.head_dlna_by_uuid_description_xml(uu_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str uu_id: Server UuId (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.head_dlna_by_uuid_description_xml_with_http_info(uu_id, **kwargs)  # noqa: E501
        else:
            (data) = self.head_dlna_by_uuid_description_xml_with_http_info(uu_id, **kwargs)  # noqa: E501
            return data

    def head_dlna_by_uuid_description_xml_with_http_info(self, uu_id, **kwargs):  # noqa: E501
        """Gets dlna server info  # noqa: E501

        No authentication required  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.head_dlna_by_uuid_description_xml_with_http_info(uu_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str uu_id: Server UuId (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['uu_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method head_dlna_by_uuid_description_xml" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'uu_id' is set
        if ('uu_id' not in params or
                params['uu_id'] is None):
            raise ValueError("Missing the required parameter `uu_id` when calling `head_dlna_by_uuid_description_xml`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'uu_id' in params:
            path_params['UuId'] = params['uu_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/Dlna/{UuId}/description.xml', 'HEAD',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_dlna_by_uuid_connectionmanager_control(self, body, uu_id, **kwargs):  # noqa: E501
        """Processes a control request  # noqa: E501

        No authentication required  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_dlna_by_uuid_connectionmanager_control(body, uu_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param Object body: Binary stream (required)
        :param str uu_id: Server UuId (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_dlna_by_uuid_connectionmanager_control_with_http_info(body, uu_id, **kwargs)  # noqa: E501
        else:
            (data) = self.post_dlna_by_uuid_connectionmanager_control_with_http_info(body, uu_id, **kwargs)  # noqa: E501
            return data

    def post_dlna_by_uuid_connectionmanager_control_with_http_info(self, body, uu_id, **kwargs):  # noqa: E501
        """Processes a control request  # noqa: E501

        No authentication required  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_dlna_by_uuid_connectionmanager_control_with_http_info(body, uu_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param Object body: Binary stream (required)
        :param str uu_id: Server UuId (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'uu_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_dlna_by_uuid_connectionmanager_control" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `post_dlna_by_uuid_connectionmanager_control`")  # noqa: E501
        # verify the required parameter 'uu_id' is set
        if ('uu_id' not in params or
                params['uu_id'] is None):
            raise ValueError("Missing the required parameter `uu_id` when calling `post_dlna_by_uuid_connectionmanager_control`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'uu_id' in params:
            path_params['UuId'] = params['uu_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/octet-stream'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/Dlna/{UuId}/connectionmanager/control', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_dlna_by_uuid_contentdirectory_control(self, body, uu_id, **kwargs):  # noqa: E501
        """Processes a control request  # noqa: E501

        No authentication required  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_dlna_by_uuid_contentdirectory_control(body, uu_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param Object body: Binary stream (required)
        :param str uu_id: Server UuId (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_dlna_by_uuid_contentdirectory_control_with_http_info(body, uu_id, **kwargs)  # noqa: E501
        else:
            (data) = self.post_dlna_by_uuid_contentdirectory_control_with_http_info(body, uu_id, **kwargs)  # noqa: E501
            return data

    def post_dlna_by_uuid_contentdirectory_control_with_http_info(self, body, uu_id, **kwargs):  # noqa: E501
        """Processes a control request  # noqa: E501

        No authentication required  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_dlna_by_uuid_contentdirectory_control_with_http_info(body, uu_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param Object body: Binary stream (required)
        :param str uu_id: Server UuId (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'uu_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_dlna_by_uuid_contentdirectory_control" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `post_dlna_by_uuid_contentdirectory_control`")  # noqa: E501
        # verify the required parameter 'uu_id' is set
        if ('uu_id' not in params or
                params['uu_id'] is None):
            raise ValueError("Missing the required parameter `uu_id` when calling `post_dlna_by_uuid_contentdirectory_control`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'uu_id' in params:
            path_params['UuId'] = params['uu_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/octet-stream'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/Dlna/{UuId}/contentdirectory/control', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class TaskTriggerInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'type': 'str',
        'time_of_day_ticks': 'int',
        'interval_ticks': 'int',
        'system_event': 'SystemEvent',
        'day_of_week': 'DayOfWeek',
        'max_runtime_ticks': 'int'
    }

    attribute_map = {
        'type': 'Type',
        'time_of_day_ticks': 'TimeOfDayTicks',
        'interval_ticks': 'IntervalTicks',
        'system_event': 'SystemEvent',
        'day_of_week': 'DayOfWeek',
        'max_runtime_ticks': 'MaxRuntimeTicks'
    }

    def __init__(self, type=None, time_of_day_ticks=None, interval_ticks=None, system_event=None, day_of_week=None, max_runtime_ticks=None):  # noqa: E501
        """TaskTriggerInfo - a model defined in Swagger"""  # noqa: E501
        self._type = None
        self._time_of_day_ticks = None
        self._interval_ticks = None
        self._system_event = None
        self._day_of_week = None
        self._max_runtime_ticks = None
        self.discriminator = None
        if type is not None:
            self.type = type
        if time_of_day_ticks is not None:
            self.time_of_day_ticks = time_of_day_ticks
        if interval_ticks is not None:
            self.interval_ticks = interval_ticks
        if system_event is not None:
            self.system_event = system_event
        if day_of_week is not None:
            self.day_of_week = day_of_week
        if max_runtime_ticks is not None:
            self.max_runtime_ticks = max_runtime_ticks

    @property
    def type(self):
        """Gets the type of this TaskTriggerInfo.  # noqa: E501

        The type.  # noqa: E501

        :return: The type of this TaskTriggerInfo.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this TaskTriggerInfo.

        The type.  # noqa: E501

        :param type: The type of this TaskTriggerInfo.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def time_of_day_ticks(self):
        """Gets the time_of_day_ticks of this TaskTriggerInfo.  # noqa: E501

        The time of day.  # noqa: E501

        :return: The time_of_day_ticks of this TaskTriggerInfo.  # noqa: E501
        :rtype: int
        """
        return self._time_of_day_ticks

    @time_of_day_ticks.setter
    def time_of_day_ticks(self, time_of_day_ticks):
        """Sets the time_of_day_ticks of this TaskTriggerInfo.

        The time of day.  # noqa: E501

        :param time_of_day_ticks: The time_of_day_ticks of this TaskTriggerInfo.  # noqa: E501
        :type: int
        """

        self._time_of_day_ticks = time_of_day_ticks

    @property
    def interval_ticks(self):
        """Gets the interval_ticks of this TaskTriggerInfo.  # noqa: E501

        The interval.  # noqa: E501

        :return: The interval_ticks of this TaskTriggerInfo.  # noqa: E501
        :rtype: int
        """
        return self._interval_ticks

    @interval_ticks.setter
    def interval_ticks(self, interval_ticks):
        """Sets the interval_ticks of this TaskTriggerInfo.

        The interval.  # noqa: E501

        :param interval_ticks: The interval_ticks of this TaskTriggerInfo.  # noqa: E501
        :type: int
        """

        self._interval_ticks = interval_ticks

    @property
    def system_event(self):
        """Gets the system_event of this TaskTriggerInfo.  # noqa: E501


        :return: The system_event of this TaskTriggerInfo.  # noqa: E501
        :rtype: SystemEvent
        """
        return self._system_event

    @system_event.setter
    def system_event(self, system_event):
        """Sets the system_event of this TaskTriggerInfo.


        :param system_event: The system_event of this TaskTriggerInfo.  # noqa: E501
        :type: SystemEvent
        """

        self._system_event = system_event

    @property
    def day_of_week(self):
        """Gets the day_of_week of this TaskTriggerInfo.  # noqa: E501


        :return: The day_of_week of this TaskTriggerInfo.  # noqa: E501
        :rtype: DayOfWeek
        """
        return self._day_of_week

    @day_of_week.setter
    def day_of_week(self, day_of_week):
        """Sets the day_of_week of this TaskTriggerInfo.


        :param day_of_week: The day_of_week of this TaskTriggerInfo.  # noqa: E501
        :type: DayOfWeek
        """

        self._day_of_week = day_of_week

    @property
    def max_runtime_ticks(self):
        """Gets the max_runtime_ticks of this TaskTriggerInfo.  # noqa: E501

        The maximum runtime ticks.  # noqa: E501

        :return: The max_runtime_ticks of this TaskTriggerInfo.  # noqa: E501
        :rtype: int
        """
        return self._max_runtime_ticks

    @max_runtime_ticks.setter
    def max_runtime_ticks(self, max_runtime_ticks):
        """Sets the max_runtime_ticks of this TaskTriggerInfo.

        The maximum runtime ticks.  # noqa: E501

        :param max_runtime_ticks: The max_runtime_ticks of this TaskTriggerInfo.  # noqa: E501
        :type: int
        """

        self._max_runtime_ticks = max_runtime_ticks

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TaskTriggerInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TaskTriggerInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class UICommand(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'command_type': 'EnumsUICommandType',
        'command_id': 'str',
        'is_visible': 'bool',
        'is_enabled': 'bool',
        'caption': 'str',
        'set_focus': 'bool',
        'confirmation_prompt': 'str'
    }

    attribute_map = {
        'command_type': 'CommandType',
        'command_id': 'CommandId',
        'is_visible': 'IsVisible',
        'is_enabled': 'IsEnabled',
        'caption': 'Caption',
        'set_focus': 'SetFocus',
        'confirmation_prompt': 'ConfirmationPrompt'
    }

    def __init__(self, command_type=None, command_id=None, is_visible=None, is_enabled=None, caption=None, set_focus=None, confirmation_prompt=None):  # noqa: E501
        """UICommand - a model defined in Swagger"""  # noqa: E501
        self._command_type = None
        self._command_id = None
        self._is_visible = None
        self._is_enabled = None
        self._caption = None
        self._set_focus = None
        self._confirmation_prompt = None
        self.discriminator = None
        if command_type is not None:
            self.command_type = command_type
        if command_id is not None:
            self.command_id = command_id
        if is_visible is not None:
            self.is_visible = is_visible
        if is_enabled is not None:
            self.is_enabled = is_enabled
        if caption is not None:
            self.caption = caption
        if set_focus is not None:
            self.set_focus = set_focus
        if confirmation_prompt is not None:
            self.confirmation_prompt = confirmation_prompt

    @property
    def command_type(self):
        """Gets the command_type of this UICommand.  # noqa: E501


        :return: The command_type of this UICommand.  # noqa: E501
        :rtype: EnumsUICommandType
        """
        return self._command_type

    @command_type.setter
    def command_type(self, command_type):
        """Sets the command_type of this UICommand.


        :param command_type: The command_type of this UICommand.  # noqa: E501
        :type: EnumsUICommandType
        """

        self._command_type = command_type

    @property
    def command_id(self):
        """Gets the command_id of this UICommand.  # noqa: E501


        :return: The command_id of this UICommand.  # noqa: E501
        :rtype: str
        """
        return self._command_id

    @command_id.setter
    def command_id(self, command_id):
        """Sets the command_id of this UICommand.


        :param command_id: The command_id of this UICommand.  # noqa: E501
        :type: str
        """

        self._command_id = command_id

    @property
    def is_visible(self):
        """Gets the is_visible of this UICommand.  # noqa: E501


        :return: The is_visible of this UICommand.  # noqa: E501
        :rtype: bool
        """
        return self._is_visible

    @is_visible.setter
    def is_visible(self, is_visible):
        """Sets the is_visible of this UICommand.


        :param is_visible: The is_visible of this UICommand.  # noqa: E501
        :type: bool
        """

        self._is_visible = is_visible

    @property
    def is_enabled(self):
        """Gets the is_enabled of this UICommand.  # noqa: E501


        :return: The is_enabled of this UICommand.  # noqa: E501
        :rtype: bool
        """
        return self._is_enabled

    @is_enabled.setter
    def is_enabled(self, is_enabled):
        """Sets the is_enabled of this UICommand.


        :param is_enabled: The is_enabled of this UICommand.  # noqa: E501
        :type: bool
        """

        self._is_enabled = is_enabled

    @property
    def caption(self):
        """Gets the caption of this UICommand.  # noqa: E501


        :return: The caption of this UICommand.  # noqa: E501
        :rtype: str
        """
        return self._caption

    @caption.setter
    def caption(self, caption):
        """Sets the caption of this UICommand.


        :param caption: The caption of this UICommand.  # noqa: E501
        :type: str
        """

        self._caption = caption

    @property
    def set_focus(self):
        """Gets the set_focus of this UICommand.  # noqa: E501


        :return: The set_focus of this UICommand.  # noqa: E501
        :rtype: bool
        """
        return self._set_focus

    @set_focus.setter
    def set_focus(self, set_focus):
        """Sets the set_focus of this UICommand.


        :param set_focus: The set_focus of this UICommand.  # noqa: E501
        :type: bool
        """

        self._set_focus = set_focus

    @property
    def confirmation_prompt(self):
        """Gets the confirmation_prompt of this UICommand.  # noqa: E501


        :return: The confirmation_prompt of this UICommand.  # noqa: E501
        :rtype: str
        """
        return self._confirmation_prompt

    @confirmation_prompt.setter
    def confirmation_prompt(self, confirmation_prompt):
        """Sets the confirmation_prompt of this UICommand.


        :param confirmation_prompt: The confirmation_prompt of this UICommand.  # noqa: E501
        :type: str
        """

        self._confirmation_prompt = confirmation_prompt

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UICommand, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UICommand):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class PlaylistsAddToPlaylistInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'item_count': 'int',
        'contains_duplicates': 'bool'
    }

    attribute_map = {
        'item_count': 'ItemCount',
        'contains_duplicates': 'ContainsDuplicates'
    }

    def __init__(self, item_count=None, contains_duplicates=None):  # noqa: E501
        """PlaylistsAddToPlaylistInfo - a model defined in Swagger"""  # noqa: E501
        self._item_count = None
        self._contains_duplicates = None
        self.discriminator = None
        if item_count is not None:
            self.item_count = item_count
        if contains_duplicates is not None:
            self.contains_duplicates = contains_duplicates

    @property
    def item_count(self):
        """Gets the item_count of this PlaylistsAddToPlaylistInfo.  # noqa: E501


        :return: The item_count of this PlaylistsAddToPlaylistInfo.  # noqa: E501
        :rtype: int
        """
        return self._item_count

    @item_count.setter
    def item_count(self, item_count):
        """Sets the item_count of this PlaylistsAddToPlaylistInfo.


        :param item_count: The item_count of this PlaylistsAddToPlaylistInfo.  # noqa: E501
        :type: int
        """

        self._item_count = item_count

    @property
    def contains_duplicates(self):
        """Gets the contains_duplicates of this PlaylistsAddToPlaylistInfo.  # noqa: E501


        :return: The contains_duplicates of this PlaylistsAddToPlaylistInfo.  # noqa: E501
        :rtype: bool
        """
        return self._contains_duplicates

    @contains_duplicates.setter
    def contains_duplicates(self, contains_duplicates):
        """Sets the contains_duplicates of this PlaylistsAddToPlaylistInfo.


        :param contains_duplicates: The contains_duplicates of this PlaylistsAddToPlaylistInfo.  # noqa: E501
        :type: bool
        """

        self._contains_duplicates = contains_duplicates

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PlaylistsAddToPlaylistInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PlaylistsAddToPlaylistInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class DevicesDeviceInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'id': 'str',
        'internal_id': 'int',
        'reported_device_id': 'str',
        'last_user_name': 'str',
        'app_name': 'str',
        'app_version': 'str',
        'last_user_id': 'str',
        'date_last_activity': 'datetime',
        'icon_url': 'str',
        'ip_address': 'str'
    }

    attribute_map = {
        'name': 'Name',
        'id': 'Id',
        'internal_id': 'InternalId',
        'reported_device_id': 'ReportedDeviceId',
        'last_user_name': 'LastUserName',
        'app_name': 'AppName',
        'app_version': 'AppVersion',
        'last_user_id': 'LastUserId',
        'date_last_activity': 'DateLastActivity',
        'icon_url': 'IconUrl',
        'ip_address': 'IpAddress'
    }

    def __init__(self, name=None, id=None, internal_id=None, reported_device_id=None, last_user_name=None, app_name=None, app_version=None, last_user_id=None, date_last_activity=None, icon_url=None, ip_address=None):  # noqa: E501
        """DevicesDeviceInfo - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._id = None
        self._internal_id = None
        self._reported_device_id = None
        self._last_user_name = None
        self._app_name = None
        self._app_version = None
        self._last_user_id = None
        self._date_last_activity = None
        self._icon_url = None
        self._ip_address = None
        self.discriminator = None
        if name is not None:
            self.name = name
        if id is not None:
            self.id = id
        if internal_id is not None:
            self.internal_id = internal_id
        if reported_device_id is not None:
            self.reported_device_id = reported_device_id
        if last_user_name is not None:
            self.last_user_name = last_user_name
        if app_name is not None:
            self.app_name = app_name
        if app_version is not None:
            self.app_version = app_version
        if last_user_id is not None:
            self.last_user_id = last_user_id
        if date_last_activity is not None:
            self.date_last_activity = date_last_activity
        if icon_url is not None:
            self.icon_url = icon_url
        if ip_address is not None:
            self.ip_address = ip_address

    @property
    def name(self):
        """Gets the name of this DevicesDeviceInfo.  # noqa: E501


        :return: The name of this DevicesDeviceInfo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this DevicesDeviceInfo.


        :param name: The name of this DevicesDeviceInfo.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def id(self):
        """Gets the id of this DevicesDeviceInfo.  # noqa: E501

        The identifier.  # noqa: E501

        :return: The id of this DevicesDeviceInfo.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DevicesDeviceInfo.

        The identifier.  # noqa: E501

        :param id: The id of this DevicesDeviceInfo.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def internal_id(self):
        """Gets the internal_id of this DevicesDeviceInfo.  # noqa: E501


        :return: The internal_id of this DevicesDeviceInfo.  # noqa: E501
        :rtype: int
        """
        return self._internal_id

    @internal_id.setter
    def internal_id(self, internal_id):
        """Sets the internal_id of this DevicesDeviceInfo.


        :param internal_id: The internal_id of this DevicesDeviceInfo.  # noqa: E501
        :type: int
        """

        self._internal_id = internal_id

    @property
    def reported_device_id(self):
        """Gets the reported_device_id of this DevicesDeviceInfo.  # noqa: E501


        :return: The reported_device_id of this DevicesDeviceInfo.  # noqa: E501
        :rtype: str
        """
        return self._reported_device_id

    @reported_device_id.setter
    def reported_device_id(self, reported_device_id):
        """Sets the reported_device_id of this DevicesDeviceInfo.


        :param reported_device_id: The reported_device_id of this DevicesDeviceInfo.  # noqa: E501
        :type: str
        """

        self._reported_device_id = reported_device_id

    @property
    def last_user_name(self):
        """Gets the last_user_name of this DevicesDeviceInfo.  # noqa: E501

        The last name of the user.  # noqa: E501

        :return: The last_user_name of this DevicesDeviceInfo.  # noqa: E501
        :rtype: str
        """
        return self._last_user_name

    @last_user_name.setter
    def last_user_name(self, last_user_name):
        """Sets the last_user_name of this DevicesDeviceInfo.

        The last name of the user.  # noqa: E501

        :param last_user_name: The last_user_name of this DevicesDeviceInfo.  # noqa: E501
        :type: str
        """

        self._last_user_name = last_user_name

    @property
    def app_name(self):
        """Gets the app_name of this DevicesDeviceInfo.  # noqa: E501

        The name of the application.  # noqa: E501

        :return: The app_name of this DevicesDeviceInfo.  # noqa: E501
        :rtype: str
        """
        return self._app_name

    @app_name.setter
    def app_name(self, app_name):
        """Sets the app_name of this DevicesDeviceInfo.

        The name of the application.  # noqa: E501

        :param app_name: The app_name of this DevicesDeviceInfo.  # noqa: E501
        :type: str
        """

        self._app_name = app_name

    @property
    def app_version(self):
        """Gets the app_version of this DevicesDeviceInfo.  # noqa: E501

        The application version.  # noqa: E501

        :return: The app_version of this DevicesDeviceInfo.  # noqa: E501
        :rtype: str
        """
        return self._app_version

    @app_version.setter
    def app_version(self, app_version):
        """Sets the app_version of this DevicesDeviceInfo.

        The application version.  # noqa: E501

        :param app_version: The app_version of this DevicesDeviceInfo.  # noqa: E501
        :type: str
        """

        self._app_version = app_version

    @property
    def last_user_id(self):
        """Gets the last_user_id of this DevicesDeviceInfo.  # noqa: E501

        The last user identifier.  # noqa: E501

        :return: The last_user_id of this DevicesDeviceInfo.  # noqa: E501
        :rtype: str
        """
        return self._last_user_id

    @last_user_id.setter
    def last_user_id(self, last_user_id):
        """Sets the last_user_id of this DevicesDeviceInfo.

        The last user identifier.  # noqa: E501

        :param last_user_id: The last_user_id of this DevicesDeviceInfo.  # noqa: E501
        :type: str
        """

        self._last_user_id = last_user_id

    @property
    def date_last_activity(self):
        """Gets the date_last_activity of this DevicesDeviceInfo.  # noqa: E501


        :return: The date_last_activity of this DevicesDeviceInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._date_last_activity

    @date_last_activity.setter
    def date_last_activity(self, date_last_activity):
        """Sets the date_last_activity of this DevicesDeviceInfo.


        :param date_last_activity: The date_last_activity of this DevicesDeviceInfo.  # noqa: E501
        :type: datetime
        """

        self._date_last_activity = date_last_activity

    @property
    def icon_url(self):
        """Gets the icon_url of this DevicesDeviceInfo.  # noqa: E501


        :return: The icon_url of this DevicesDeviceInfo.  # noqa: E501
        :rtype: str
        """
        return self._icon_url

    @icon_url.setter
    def icon_url(self, icon_url):
        """Sets the icon_url of this DevicesDeviceInfo.


        :param icon_url: The icon_url of this DevicesDeviceInfo.  # noqa: E501
        :type: str
        """

        self._icon_url = icon_url

    @property
    def ip_address(self):
        """Gets the ip_address of this DevicesDeviceInfo.  # noqa: E501


        :return: The ip_address of this DevicesDeviceInfo.  # noqa: E501
        :rtype: str
        """
        return self._ip_address

    @ip_address.setter
    def ip_address(self, ip_address):
        """Sets the ip_address of this DevicesDeviceInfo.


        :param ip_address: The ip_address of this DevicesDeviceInfo.  # noqa: E501
        :type: str
        """

        self._ip_address = ip_address

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DevicesDeviceInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DevicesDeviceInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class PersonLookupInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'path': 'str',
        'metadata_language': 'str',
        'metadata_country_code': 'str',
        'metadata_languages': 'list[GlobalizationCultureDto]',
        'provider_ids': 'ProviderIdDictionary',
        'year': 'int',
        'index_number': 'int',
        'parent_index_number': 'int',
        'premiere_date': 'datetime',
        'is_automated': 'bool',
        'enable_adult_metadata': 'bool'
    }

    attribute_map = {
        'name': 'Name',
        'path': 'Path',
        'metadata_language': 'MetadataLanguage',
        'metadata_country_code': 'MetadataCountryCode',
        'metadata_languages': 'MetadataLanguages',
        'provider_ids': 'ProviderIds',
        'year': 'Year',
        'index_number': 'IndexNumber',
        'parent_index_number': 'ParentIndexNumber',
        'premiere_date': 'PremiereDate',
        'is_automated': 'IsAutomated',
        'enable_adult_metadata': 'EnableAdultMetadata'
    }

    def __init__(self, name=None, path=None, metadata_language=None, metadata_country_code=None, metadata_languages=None, provider_ids=None, year=None, index_number=None, parent_index_number=None, premiere_date=None, is_automated=None, enable_adult_metadata=None):  # noqa: E501
        """PersonLookupInfo - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._path = None
        self._metadata_language = None
        self._metadata_country_code = None
        self._metadata_languages = None
        self._provider_ids = None
        self._year = None
        self._index_number = None
        self._parent_index_number = None
        self._premiere_date = None
        self._is_automated = None
        self._enable_adult_metadata = None
        self.discriminator = None
        if name is not None:
            self.name = name
        if path is not None:
            self.path = path
        if metadata_language is not None:
            self.metadata_language = metadata_language
        if metadata_country_code is not None:
            self.metadata_country_code = metadata_country_code
        if metadata_languages is not None:
            self.metadata_languages = metadata_languages
        if provider_ids is not None:
            self.provider_ids = provider_ids
        if year is not None:
            self.year = year
        if index_number is not None:
            self.index_number = index_number
        if parent_index_number is not None:
            self.parent_index_number = parent_index_number
        if premiere_date is not None:
            self.premiere_date = premiere_date
        if is_automated is not None:
            self.is_automated = is_automated
        if enable_adult_metadata is not None:
            self.enable_adult_metadata = enable_adult_metadata

    @property
    def name(self):
        """Gets the name of this PersonLookupInfo.  # noqa: E501

        The name.  # noqa: E501

        :return: The name of this PersonLookupInfo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this PersonLookupInfo.

        The name.  # noqa: E501

        :param name: The name of this PersonLookupInfo.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def path(self):
        """Gets the path of this PersonLookupInfo.  # noqa: E501


        :return: The path of this PersonLookupInfo.  # noqa: E501
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this PersonLookupInfo.


        :param path: The path of this PersonLookupInfo.  # noqa: E501
        :type: str
        """

        self._path = path

    @property
    def metadata_language(self):
        """Gets the metadata_language of this PersonLookupInfo.  # noqa: E501

        The metadata language.  # noqa: E501

        :return: The metadata_language of this PersonLookupInfo.  # noqa: E501
        :rtype: str
        """
        return self._metadata_language

    @metadata_language.setter
    def metadata_language(self, metadata_language):
        """Sets the metadata_language of this PersonLookupInfo.

        The metadata language.  # noqa: E501

        :param metadata_language: The metadata_language of this PersonLookupInfo.  # noqa: E501
        :type: str
        """

        self._metadata_language = metadata_language

    @property
    def metadata_country_code(self):
        """Gets the metadata_country_code of this PersonLookupInfo.  # noqa: E501

        The metadata country code.  # noqa: E501

        :return: The metadata_country_code of this PersonLookupInfo.  # noqa: E501
        :rtype: str
        """
        return self._metadata_country_code

    @metadata_country_code.setter
    def metadata_country_code(self, metadata_country_code):
        """Sets the metadata_country_code of this PersonLookupInfo.

        The metadata country code.  # noqa: E501

        :param metadata_country_code: The metadata_country_code of this PersonLookupInfo.  # noqa: E501
        :type: str
        """

        self._metadata_country_code = metadata_country_code

    @property
    def metadata_languages(self):
        """Gets the metadata_languages of this PersonLookupInfo.  # noqa: E501


        :return: The metadata_languages of this PersonLookupInfo.  # noqa: E501
        :rtype: list[GlobalizationCultureDto]
        """
        return self._metadata_languages

    @metadata_languages.setter
    def metadata_languages(self, metadata_languages):
        """Sets the metadata_languages of this PersonLookupInfo.


        :param metadata_languages: The metadata_languages of this PersonLookupInfo.  # noqa: E501
        :type: list[GlobalizationCultureDto]
        """

        self._metadata_languages = metadata_languages

    @property
    def provider_ids(self):
        """Gets the provider_ids of this PersonLookupInfo.  # noqa: E501


        :return: The provider_ids of this PersonLookupInfo.  # noqa: E501
        :rtype: ProviderIdDictionary
        """
        return self._provider_ids

    @provider_ids.setter
    def provider_ids(self, provider_ids):
        """Sets the provider_ids of this PersonLookupInfo.


        :param provider_ids: The provider_ids of this PersonLookupInfo.  # noqa: E501
        :type: ProviderIdDictionary
        """

        self._provider_ids = provider_ids

    @property
    def year(self):
        """Gets the year of this PersonLookupInfo.  # noqa: E501

        The year.  # noqa: E501

        :return: The year of this PersonLookupInfo.  # noqa: E501
        :rtype: int
        """
        return self._year

    @year.setter
    def year(self, year):
        """Sets the year of this PersonLookupInfo.

        The year.  # noqa: E501

        :param year: The year of this PersonLookupInfo.  # noqa: E501
        :type: int
        """

        self._year = year

    @property
    def index_number(self):
        """Gets the index_number of this PersonLookupInfo.  # noqa: E501


        :return: The index_number of this PersonLookupInfo.  # noqa: E501
        :rtype: int
        """
        return self._index_number

    @index_number.setter
    def index_number(self, index_number):
        """Sets the index_number of this PersonLookupInfo.


        :param index_number: The index_number of this PersonLookupInfo.  # noqa: E501
        :type: int
        """

        self._index_number = index_number

    @property
    def parent_index_number(self):
        """Gets the parent_index_number of this PersonLookupInfo.  # noqa: E501


        :return: The parent_index_number of this PersonLookupInfo.  # noqa: E501
        :rtype: int
        """
        return self._parent_index_number

    @parent_index_number.setter
    def parent_index_number(self, parent_index_number):
        """Sets the parent_index_number of this PersonLookupInfo.


        :param parent_index_number: The parent_index_number of this PersonLookupInfo.  # noqa: E501
        :type: int
        """

        self._parent_index_number = parent_index_number

    @property
    def premiere_date(self):
        """Gets the premiere_date of this PersonLookupInfo.  # noqa: E501


        :return: The premiere_date of this PersonLookupInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._premiere_date

    @premiere_date.setter
    def premiere_date(self, premiere_date):
        """Sets the premiere_date of this PersonLookupInfo.


        :param premiere_date: The premiere_date of this PersonLookupInfo.  # noqa: E501
        :type: datetime
        """

        self._premiere_date = premiere_date

    @property
    def is_automated(self):
        """Gets the is_automated of this PersonLookupInfo.  # noqa: E501


        :return: The is_automated of this PersonLookupInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_automated

    @is_automated.setter
    def is_automated(self, is_automated):
        """Sets the is_automated of this PersonLookupInfo.


        :param is_automated: The is_automated of this PersonLookupInfo.  # noqa: E501
        :type: bool
        """

        self._is_automated = is_automated

    @property
    def enable_adult_metadata(self):
        """Gets the enable_adult_metadata of this PersonLookupInfo.  # noqa: E501


        :return: The enable_adult_metadata of this PersonLookupInfo.  # noqa: E501
        :rtype: bool
        """
        return self._enable_adult_metadata

    @enable_adult_metadata.setter
    def enable_adult_metadata(self, enable_adult_metadata):
        """Sets the enable_adult_metadata of this PersonLookupInfo.


        :param enable_adult_metadata: The enable_adult_metadata of this PersonLookupInfo.  # noqa: E501
        :type: bool
        """

        self._enable_adult_metadata = enable_adult_metadata

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PersonLookupInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PersonLookupInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class GlobalizationCultureDto(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'display_name': 'str',
        'two_letter_iso_language_name': 'str',
        'three_letter_iso_language_name': 'str',
        'three_letter_iso_language_names': 'list[str]',
        'two_letter_iso_language_names': 'list[str]'
    }

    attribute_map = {
        'name': 'Name',
        'display_name': 'DisplayName',
        'two_letter_iso_language_name': 'TwoLetterISOLanguageName',
        'three_letter_iso_language_name': 'ThreeLetterISOLanguageName',
        'three_letter_iso_language_names': 'ThreeLetterISOLanguageNames',
        'two_letter_iso_language_names': 'TwoLetterISOLanguageNames'
    }

    def __init__(self, name=None, display_name=None, two_letter_iso_language_name=None, three_letter_iso_language_name=None, three_letter_iso_language_names=None, two_letter_iso_language_names=None):  # noqa: E501
        """GlobalizationCultureDto - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._display_name = None
        self._two_letter_iso_language_name = None
        self._three_letter_iso_language_name = None
        self._three_letter_iso_language_names = None
        self._two_letter_iso_language_names = None
        self.discriminator = None
        if name is not None:
            self.name = name
        if display_name is not None:
            self.display_name = display_name
        if two_letter_iso_language_name is not None:
            self.two_letter_iso_language_name = two_letter_iso_language_name
        if three_letter_iso_language_name is not None:
            self.three_letter_iso_language_name = three_letter_iso_language_name
        if three_letter_iso_language_names is not None:
            self.three_letter_iso_language_names = three_letter_iso_language_names
        if two_letter_iso_language_names is not None:
            self.two_letter_iso_language_names = two_letter_iso_language_names

    @property
    def name(self):
        """Gets the name of this GlobalizationCultureDto.  # noqa: E501

        The name.  # noqa: E501

        :return: The name of this GlobalizationCultureDto.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this GlobalizationCultureDto.

        The name.  # noqa: E501

        :param name: The name of this GlobalizationCultureDto.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def display_name(self):
        """Gets the display_name of this GlobalizationCultureDto.  # noqa: E501

        The display name.  # noqa: E501

        :return: The display_name of this GlobalizationCultureDto.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this GlobalizationCultureDto.

        The display name.  # noqa: E501

        :param display_name: The display_name of this GlobalizationCultureDto.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def two_letter_iso_language_name(self):
        """Gets the two_letter_iso_language_name of this GlobalizationCultureDto.  # noqa: E501

        The name of the two letter ISO language.  # noqa: E501

        :return: The two_letter_iso_language_name of this GlobalizationCultureDto.  # noqa: E501
        :rtype: str
        """
        return self._two_letter_iso_language_name

    @two_letter_iso_language_name.setter
    def two_letter_iso_language_name(self, two_letter_iso_language_name):
        """Sets the two_letter_iso_language_name of this GlobalizationCultureDto.

        The name of the two letter ISO language.  # noqa: E501

        :param two_letter_iso_language_name: The two_letter_iso_language_name of this GlobalizationCultureDto.  # noqa: E501
        :type: str
        """

        self._two_letter_iso_language_name = two_letter_iso_language_name

    @property
    def three_letter_iso_language_name(self):
        """Gets the three_letter_iso_language_name of this GlobalizationCultureDto.  # noqa: E501

        The name of the three letter ISO language.  # noqa: E501

        :return: The three_letter_iso_language_name of this GlobalizationCultureDto.  # noqa: E501
        :rtype: str
        """
        return self._three_letter_iso_language_name

    @three_letter_iso_language_name.setter
    def three_letter_iso_language_name(self, three_letter_iso_language_name):
        """Sets the three_letter_iso_language_name of this GlobalizationCultureDto.

        The name of the three letter ISO language.  # noqa: E501

        :param three_letter_iso_language_name: The three_letter_iso_language_name of this GlobalizationCultureDto.  # noqa: E501
        :type: str
        """

        self._three_letter_iso_language_name = three_letter_iso_language_name

    @property
    def three_letter_iso_language_names(self):
        """Gets the three_letter_iso_language_names of this GlobalizationCultureDto.  # noqa: E501


        :return: The three_letter_iso_language_names of this GlobalizationCultureDto.  # noqa: E501
        :rtype: list[str]
        """
        return self._three_letter_iso_language_names

    @three_letter_iso_language_names.setter
    def three_letter_iso_language_names(self, three_letter_iso_language_names):
        """Sets the three_letter_iso_language_names of this GlobalizationCultureDto.


        :param three_letter_iso_language_names: The three_letter_iso_language_names of this GlobalizationCultureDto.  # noqa: E501
        :type: list[str]
        """

        self._three_letter_iso_language_names = three_letter_iso_language_names

    @property
    def two_letter_iso_language_names(self):
        """Gets the two_letter_iso_language_names of this GlobalizationCultureDto.  # noqa: E501


        :return: The two_letter_iso_language_names of this GlobalizationCultureDto.  # noqa: E501
        :rtype: list[str]
        """
        return self._two_letter_iso_language_names

    @two_letter_iso_language_names.setter
    def two_letter_iso_language_names(self, two_letter_iso_language_names):
        """Sets the two_letter_iso_language_names of this GlobalizationCultureDto.


        :param two_letter_iso_language_names: The two_letter_iso_language_names of this GlobalizationCultureDto.  # noqa: E501
        :type: list[str]
        """

        self._two_letter_iso_language_names = two_letter_iso_language_names

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GlobalizationCultureDto, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GlobalizationCultureDto):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class ProcessRunMetricsProcessMetricPoint(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'time': 'str',
        'cpu_percent': 'float',
        'virtual_memory': 'float',
        'working_set': 'float'
    }

    attribute_map = {
        'time': 'Time',
        'cpu_percent': 'CpuPercent',
        'virtual_memory': 'VirtualMemory',
        'working_set': 'WorkingSet'
    }

    def __init__(self, time=None, cpu_percent=None, virtual_memory=None, working_set=None):  # noqa: E501
        """ProcessRunMetricsProcessMetricPoint - a model defined in Swagger"""  # noqa: E501
        self._time = None
        self._cpu_percent = None
        self._virtual_memory = None
        self._working_set = None
        self.discriminator = None
        if time is not None:
            self.time = time
        if cpu_percent is not None:
            self.cpu_percent = cpu_percent
        if virtual_memory is not None:
            self.virtual_memory = virtual_memory
        if working_set is not None:
            self.working_set = working_set

    @property
    def time(self):
        """Gets the time of this ProcessRunMetricsProcessMetricPoint.  # noqa: E501

        The time.  # noqa: E501

        :return: The time of this ProcessRunMetricsProcessMetricPoint.  # noqa: E501
        :rtype: str
        """
        return self._time

    @time.setter
    def time(self, time):
        """Sets the time of this ProcessRunMetricsProcessMetricPoint.

        The time.  # noqa: E501

        :param time: The time of this ProcessRunMetricsProcessMetricPoint.  # noqa: E501
        :type: str
        """

        self._time = time

    @property
    def cpu_percent(self):
        """Gets the cpu_percent of this ProcessRunMetricsProcessMetricPoint.  # noqa: E501

        The cpu percent.  # noqa: E501

        :return: The cpu_percent of this ProcessRunMetricsProcessMetricPoint.  # noqa: E501
        :rtype: float
        """
        return self._cpu_percent

    @cpu_percent.setter
    def cpu_percent(self, cpu_percent):
        """Sets the cpu_percent of this ProcessRunMetricsProcessMetricPoint.

        The cpu percent.  # noqa: E501

        :param cpu_percent: The cpu_percent of this ProcessRunMetricsProcessMetricPoint.  # noqa: E501
        :type: float
        """

        self._cpu_percent = cpu_percent

    @property
    def virtual_memory(self):
        """Gets the virtual_memory of this ProcessRunMetricsProcessMetricPoint.  # noqa: E501

        The virtual memory.  # noqa: E501

        :return: The virtual_memory of this ProcessRunMetricsProcessMetricPoint.  # noqa: E501
        :rtype: float
        """
        return self._virtual_memory

    @virtual_memory.setter
    def virtual_memory(self, virtual_memory):
        """Sets the virtual_memory of this ProcessRunMetricsProcessMetricPoint.

        The virtual memory.  # noqa: E501

        :param virtual_memory: The virtual_memory of this ProcessRunMetricsProcessMetricPoint.  # noqa: E501
        :type: float
        """

        self._virtual_memory = virtual_memory

    @property
    def working_set(self):
        """Gets the working_set of this ProcessRunMetricsProcessMetricPoint.  # noqa: E501

        The working set.  # noqa: E501

        :return: The working_set of this ProcessRunMetricsProcessMetricPoint.  # noqa: E501
        :rtype: float
        """
        return self._working_set

    @working_set.setter
    def working_set(self, working_set):
        """Sets the working_set of this ProcessRunMetricsProcessMetricPoint.

        The working set.  # noqa: E501

        :param working_set: The working_set of this ProcessRunMetricsProcessMetricPoint.  # noqa: E501
        :type: float
        """

        self._working_set = working_set

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ProcessRunMetricsProcessMetricPoint, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProcessRunMetricsProcessMetricPoint):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class PlaybackInfoResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'media_sources': 'list[MediaSourceInfo]',
        'play_session_id': 'str',
        'error_code': 'PlaybackErrorCode'
    }

    attribute_map = {
        'media_sources': 'MediaSources',
        'play_session_id': 'PlaySessionId',
        'error_code': 'ErrorCode'
    }

    def __init__(self, media_sources=None, play_session_id=None, error_code=None):  # noqa: E501
        """PlaybackInfoResponse - a model defined in Swagger"""  # noqa: E501
        self._media_sources = None
        self._play_session_id = None
        self._error_code = None
        self.discriminator = None
        if media_sources is not None:
            self.media_sources = media_sources
        if play_session_id is not None:
            self.play_session_id = play_session_id
        if error_code is not None:
            self.error_code = error_code

    @property
    def media_sources(self):
        """Gets the media_sources of this PlaybackInfoResponse.  # noqa: E501

        The media sources.  # noqa: E501

        :return: The media_sources of this PlaybackInfoResponse.  # noqa: E501
        :rtype: list[MediaSourceInfo]
        """
        return self._media_sources

    @media_sources.setter
    def media_sources(self, media_sources):
        """Sets the media_sources of this PlaybackInfoResponse.

        The media sources.  # noqa: E501

        :param media_sources: The media_sources of this PlaybackInfoResponse.  # noqa: E501
        :type: list[MediaSourceInfo]
        """

        self._media_sources = media_sources

    @property
    def play_session_id(self):
        """Gets the play_session_id of this PlaybackInfoResponse.  # noqa: E501

        The play session identifier.  # noqa: E501

        :return: The play_session_id of this PlaybackInfoResponse.  # noqa: E501
        :rtype: str
        """
        return self._play_session_id

    @play_session_id.setter
    def play_session_id(self, play_session_id):
        """Sets the play_session_id of this PlaybackInfoResponse.

        The play session identifier.  # noqa: E501

        :param play_session_id: The play_session_id of this PlaybackInfoResponse.  # noqa: E501
        :type: str
        """

        self._play_session_id = play_session_id

    @property
    def error_code(self):
        """Gets the error_code of this PlaybackInfoResponse.  # noqa: E501


        :return: The error_code of this PlaybackInfoResponse.  # noqa: E501
        :rtype: PlaybackErrorCode
        """
        return self._error_code

    @error_code.setter
    def error_code(self, error_code):
        """Sets the error_code of this PlaybackInfoResponse.


        :param error_code: The error_code of this PlaybackInfoResponse.  # noqa: E501
        :type: PlaybackErrorCode
        """

        self._error_code = error_code

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PlaybackInfoResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PlaybackInfoResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class UserNotificationInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'notifier_key': 'str',
        'setup_module_url': 'str',
        'service_name': 'str',
        'plugin_id': 'str',
        'friendly_name': 'str',
        'id': 'str',
        'enabled': 'bool',
        'user_ids': 'list[str]',
        'device_ids': 'list[str]',
        'library_ids': 'list[str]',
        'event_ids': 'list[str]',
        'user_id': 'str',
        'is_self_notification': 'bool',
        'group_items': 'bool',
        'options': 'dict(str, str)'
    }

    attribute_map = {
        'notifier_key': 'NotifierKey',
        'setup_module_url': 'SetupModuleUrl',
        'service_name': 'ServiceName',
        'plugin_id': 'PluginId',
        'friendly_name': 'FriendlyName',
        'id': 'Id',
        'enabled': 'Enabled',
        'user_ids': 'UserIds',
        'device_ids': 'DeviceIds',
        'library_ids': 'LibraryIds',
        'event_ids': 'EventIds',
        'user_id': 'UserId',
        'is_self_notification': 'IsSelfNotification',
        'group_items': 'GroupItems',
        'options': 'Options'
    }

    def __init__(self, notifier_key=None, setup_module_url=None, service_name=None, plugin_id=None, friendly_name=None, id=None, enabled=None, user_ids=None, device_ids=None, library_ids=None, event_ids=None, user_id=None, is_self_notification=None, group_items=None, options=None):  # noqa: E501
        """UserNotificationInfo - a model defined in Swagger"""  # noqa: E501
        self._notifier_key = None
        self._setup_module_url = None
        self._service_name = None
        self._plugin_id = None
        self._friendly_name = None
        self._id = None
        self._enabled = None
        self._user_ids = None
        self._device_ids = None
        self._library_ids = None
        self._event_ids = None
        self._user_id = None
        self._is_self_notification = None
        self._group_items = None
        self._options = None
        self.discriminator = None
        if notifier_key is not None:
            self.notifier_key = notifier_key
        if setup_module_url is not None:
            self.setup_module_url = setup_module_url
        if service_name is not None:
            self.service_name = service_name
        if plugin_id is not None:
            self.plugin_id = plugin_id
        if friendly_name is not None:
            self.friendly_name = friendly_name
        if id is not None:
            self.id = id
        if enabled is not None:
            self.enabled = enabled
        if user_ids is not None:
            self.user_ids = user_ids
        if device_ids is not None:
            self.device_ids = device_ids
        if library_ids is not None:
            self.library_ids = library_ids
        if event_ids is not None:
            self.event_ids = event_ids
        if user_id is not None:
            self.user_id = user_id
        if is_self_notification is not None:
            self.is_self_notification = is_self_notification
        if group_items is not None:
            self.group_items = group_items
        if options is not None:
            self.options = options

    @property
    def notifier_key(self):
        """Gets the notifier_key of this UserNotificationInfo.  # noqa: E501


        :return: The notifier_key of this UserNotificationInfo.  # noqa: E501
        :rtype: str
        """
        return self._notifier_key

    @notifier_key.setter
    def notifier_key(self, notifier_key):
        """Sets the notifier_key of this UserNotificationInfo.


        :param notifier_key: The notifier_key of this UserNotificationInfo.  # noqa: E501
        :type: str
        """

        self._notifier_key = notifier_key

    @property
    def setup_module_url(self):
        """Gets the setup_module_url of this UserNotificationInfo.  # noqa: E501


        :return: The setup_module_url of this UserNotificationInfo.  # noqa: E501
        :rtype: str
        """
        return self._setup_module_url

    @setup_module_url.setter
    def setup_module_url(self, setup_module_url):
        """Sets the setup_module_url of this UserNotificationInfo.


        :param setup_module_url: The setup_module_url of this UserNotificationInfo.  # noqa: E501
        :type: str
        """

        self._setup_module_url = setup_module_url

    @property
    def service_name(self):
        """Gets the service_name of this UserNotificationInfo.  # noqa: E501


        :return: The service_name of this UserNotificationInfo.  # noqa: E501
        :rtype: str
        """
        return self._service_name

    @service_name.setter
    def service_name(self, service_name):
        """Sets the service_name of this UserNotificationInfo.


        :param service_name: The service_name of this UserNotificationInfo.  # noqa: E501
        :type: str
        """

        self._service_name = service_name

    @property
    def plugin_id(self):
        """Gets the plugin_id of this UserNotificationInfo.  # noqa: E501


        :return: The plugin_id of this UserNotificationInfo.  # noqa: E501
        :rtype: str
        """
        return self._plugin_id

    @plugin_id.setter
    def plugin_id(self, plugin_id):
        """Sets the plugin_id of this UserNotificationInfo.


        :param plugin_id: The plugin_id of this UserNotificationInfo.  # noqa: E501
        :type: str
        """

        self._plugin_id = plugin_id

    @property
    def friendly_name(self):
        """Gets the friendly_name of this UserNotificationInfo.  # noqa: E501


        :return: The friendly_name of this UserNotificationInfo.  # noqa: E501
        :rtype: str
        """
        return self._friendly_name

    @friendly_name.setter
    def friendly_name(self, friendly_name):
        """Sets the friendly_name of this UserNotificationInfo.


        :param friendly_name: The friendly_name of this UserNotificationInfo.  # noqa: E501
        :type: str
        """

        self._friendly_name = friendly_name

    @property
    def id(self):
        """Gets the id of this UserNotificationInfo.  # noqa: E501


        :return: The id of this UserNotificationInfo.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this UserNotificationInfo.


        :param id: The id of this UserNotificationInfo.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def enabled(self):
        """Gets the enabled of this UserNotificationInfo.  # noqa: E501


        :return: The enabled of this UserNotificationInfo.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this UserNotificationInfo.


        :param enabled: The enabled of this UserNotificationInfo.  # noqa: E501
        :type: bool
        """

        self._enabled = enabled

    @property
    def user_ids(self):
        """Gets the user_ids of this UserNotificationInfo.  # noqa: E501

        Limit events based on user ids, for admin notifications  # noqa: E501

        :return: The user_ids of this UserNotificationInfo.  # noqa: E501
        :rtype: list[str]
        """
        return self._user_ids

    @user_ids.setter
    def user_ids(self, user_ids):
        """Sets the user_ids of this UserNotificationInfo.

        Limit events based on user ids, for admin notifications  # noqa: E501

        :param user_ids: The user_ids of this UserNotificationInfo.  # noqa: E501
        :type: list[str]
        """

        self._user_ids = user_ids

    @property
    def device_ids(self):
        """Gets the device_ids of this UserNotificationInfo.  # noqa: E501


        :return: The device_ids of this UserNotificationInfo.  # noqa: E501
        :rtype: list[str]
        """
        return self._device_ids

    @device_ids.setter
    def device_ids(self, device_ids):
        """Sets the device_ids of this UserNotificationInfo.


        :param device_ids: The device_ids of this UserNotificationInfo.  # noqa: E501
        :type: list[str]
        """

        self._device_ids = device_ids

    @property
    def library_ids(self):
        """Gets the library_ids of this UserNotificationInfo.  # noqa: E501


        :return: The library_ids of this UserNotificationInfo.  # noqa: E501
        :rtype: list[str]
        """
        return self._library_ids

    @library_ids.setter
    def library_ids(self, library_ids):
        """Sets the library_ids of this UserNotificationInfo.


        :param library_ids: The library_ids of this UserNotificationInfo.  # noqa: E501
        :type: list[str]
        """

        self._library_ids = library_ids

    @property
    def event_ids(self):
        """Gets the event_ids of this UserNotificationInfo.  # noqa: E501


        :return: The event_ids of this UserNotificationInfo.  # noqa: E501
        :rtype: list[str]
        """
        return self._event_ids

    @event_ids.setter
    def event_ids(self, event_ids):
        """Sets the event_ids of this UserNotificationInfo.


        :param event_ids: The event_ids of this UserNotificationInfo.  # noqa: E501
        :type: list[str]
        """

        self._event_ids = event_ids

    @property
    def user_id(self):
        """Gets the user_id of this UserNotificationInfo.  # noqa: E501

        Notification intended for a specific user  # noqa: E501

        :return: The user_id of this UserNotificationInfo.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this UserNotificationInfo.

        Notification intended for a specific user  # noqa: E501

        :param user_id: The user_id of this UserNotificationInfo.  # noqa: E501
        :type: str
        """

        self._user_id = user_id

    @property
    def is_self_notification(self):
        """Gets the is_self_notification of this UserNotificationInfo.  # noqa: E501


        :return: The is_self_notification of this UserNotificationInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_self_notification

    @is_self_notification.setter
    def is_self_notification(self, is_self_notification):
        """Sets the is_self_notification of this UserNotificationInfo.


        :param is_self_notification: The is_self_notification of this UserNotificationInfo.  # noqa: E501
        :type: bool
        """

        self._is_self_notification = is_self_notification

    @property
    def group_items(self):
        """Gets the group_items of this UserNotificationInfo.  # noqa: E501


        :return: The group_items of this UserNotificationInfo.  # noqa: E501
        :rtype: bool
        """
        return self._group_items

    @group_items.setter
    def group_items(self, group_items):
        """Sets the group_items of this UserNotificationInfo.


        :param group_items: The group_items of this UserNotificationInfo.  # noqa: E501
        :type: bool
        """

        self._group_items = group_items

    @property
    def options(self):
        """Gets the options of this UserNotificationInfo.  # noqa: E501

        This is for webhooks since this will cause xml serialization to fail  # noqa: E501

        :return: The options of this UserNotificationInfo.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._options

    @options.setter
    def options(self, options):
        """Sets the options of this UserNotificationInfo.

        This is for webhooks since this will cause xml serialization to fail  # noqa: E501

        :param options: The options of this UserNotificationInfo.  # noqa: E501
        :type: dict(str, str)
        """

        self._options = options

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UserNotificationInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UserNotificationInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class TranscodingInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'audio_codec': 'str',
        'video_codec': 'str',
        'sub_protocol': 'str',
        'container': 'str',
        'is_video_direct': 'bool',
        'is_audio_direct': 'bool',
        'bitrate': 'int',
        'audio_bitrate': 'int',
        'video_bitrate': 'int',
        'framerate': 'float',
        'completion_percentage': 'float',
        'transcoding_position_ticks': 'float',
        'transcoding_start_position_ticks': 'float',
        'width': 'int',
        'height': 'int',
        'audio_channels': 'int',
        'transcode_reasons': 'list[TranscodeReason]',
        'current_cpu_usage': 'float',
        'average_cpu_usage': 'float',
        'cpu_history': 'list[TupleDoubleDouble]',
        'process_statistics': 'ProcessRunMetricsProcessStatistics',
        'current_throttle': 'int',
        'video_decoder': 'str',
        'video_decoder_is_hardware': 'bool',
        'video_decoder_media_type': 'str',
        'video_decoder_hw_accel': 'str',
        'video_encoder': 'str',
        'video_encoder_is_hardware': 'bool',
        'video_encoder_media_type': 'str',
        'video_encoder_hw_accel': 'str',
        'video_pipeline_info': 'list[TranscodingVpStepInfo]',
        'subtitle_pipeline_infos': 'list[list[TranscodingVpStepInfo]]'
    }

    attribute_map = {
        'audio_codec': 'AudioCodec',
        'video_codec': 'VideoCodec',
        'sub_protocol': 'SubProtocol',
        'container': 'Container',
        'is_video_direct': 'IsVideoDirect',
        'is_audio_direct': 'IsAudioDirect',
        'bitrate': 'Bitrate',
        'audio_bitrate': 'AudioBitrate',
        'video_bitrate': 'VideoBitrate',
        'framerate': 'Framerate',
        'completion_percentage': 'CompletionPercentage',
        'transcoding_position_ticks': 'TranscodingPositionTicks',
        'transcoding_start_position_ticks': 'TranscodingStartPositionTicks',
        'width': 'Width',
        'height': 'Height',
        'audio_channels': 'AudioChannels',
        'transcode_reasons': 'TranscodeReasons',
        'current_cpu_usage': 'CurrentCpuUsage',
        'average_cpu_usage': 'AverageCpuUsage',
        'cpu_history': 'CpuHistory',
        'process_statistics': 'ProcessStatistics',
        'current_throttle': 'CurrentThrottle',
        'video_decoder': 'VideoDecoder',
        'video_decoder_is_hardware': 'VideoDecoderIsHardware',
        'video_decoder_media_type': 'VideoDecoderMediaType',
        'video_decoder_hw_accel': 'VideoDecoderHwAccel',
        'video_encoder': 'VideoEncoder',
        'video_encoder_is_hardware': 'VideoEncoderIsHardware',
        'video_encoder_media_type': 'VideoEncoderMediaType',
        'video_encoder_hw_accel': 'VideoEncoderHwAccel',
        'video_pipeline_info': 'VideoPipelineInfo',
        'subtitle_pipeline_infos': 'SubtitlePipelineInfos'
    }

    def __init__(self, audio_codec=None, video_codec=None, sub_protocol=None, container=None, is_video_direct=None, is_audio_direct=None, bitrate=None, audio_bitrate=None, video_bitrate=None, framerate=None, completion_percentage=None, transcoding_position_ticks=None, transcoding_start_position_ticks=None, width=None, height=None, audio_channels=None, transcode_reasons=None, current_cpu_usage=None, average_cpu_usage=None, cpu_history=None, process_statistics=None, current_throttle=None, video_decoder=None, video_decoder_is_hardware=None, video_decoder_media_type=None, video_decoder_hw_accel=None, video_encoder=None, video_encoder_is_hardware=None, video_encoder_media_type=None, video_encoder_hw_accel=None, video_pipeline_info=None, subtitle_pipeline_infos=None):  # noqa: E501
        """TranscodingInfo - a model defined in Swagger"""  # noqa: E501
        self._audio_codec = None
        self._video_codec = None
        self._sub_protocol = None
        self._container = None
        self._is_video_direct = None
        self._is_audio_direct = None
        self._bitrate = None
        self._audio_bitrate = None
        self._video_bitrate = None
        self._framerate = None
        self._completion_percentage = None
        self._transcoding_position_ticks = None
        self._transcoding_start_position_ticks = None
        self._width = None
        self._height = None
        self._audio_channels = None
        self._transcode_reasons = None
        self._current_cpu_usage = None
        self._average_cpu_usage = None
        self._cpu_history = None
        self._process_statistics = None
        self._current_throttle = None
        self._video_decoder = None
        self._video_decoder_is_hardware = None
        self._video_decoder_media_type = None
        self._video_decoder_hw_accel = None
        self._video_encoder = None
        self._video_encoder_is_hardware = None
        self._video_encoder_media_type = None
        self._video_encoder_hw_accel = None
        self._video_pipeline_info = None
        self._subtitle_pipeline_infos = None
        self.discriminator = None
        if audio_codec is not None:
            self.audio_codec = audio_codec
        if video_codec is not None:
            self.video_codec = video_codec
        if sub_protocol is not None:
            self.sub_protocol = sub_protocol
        if container is not None:
            self.container = container
        if is_video_direct is not None:
            self.is_video_direct = is_video_direct
        if is_audio_direct is not None:
            self.is_audio_direct = is_audio_direct
        if bitrate is not None:
            self.bitrate = bitrate
        if audio_bitrate is not None:
            self.audio_bitrate = audio_bitrate
        if video_bitrate is not None:
            self.video_bitrate = video_bitrate
        if framerate is not None:
            self.framerate = framerate
        if completion_percentage is not None:
            self.completion_percentage = completion_percentage
        if transcoding_position_ticks is not None:
            self.transcoding_position_ticks = transcoding_position_ticks
        if transcoding_start_position_ticks is not None:
            self.transcoding_start_position_ticks = transcoding_start_position_ticks
        if width is not None:
            self.width = width
        if height is not None:
            self.height = height
        if audio_channels is not None:
            self.audio_channels = audio_channels
        if transcode_reasons is not None:
            self.transcode_reasons = transcode_reasons
        if current_cpu_usage is not None:
            self.current_cpu_usage = current_cpu_usage
        if average_cpu_usage is not None:
            self.average_cpu_usage = average_cpu_usage
        if cpu_history is not None:
            self.cpu_history = cpu_history
        if process_statistics is not None:
            self.process_statistics = process_statistics
        if current_throttle is not None:
            self.current_throttle = current_throttle
        if video_decoder is not None:
            self.video_decoder = video_decoder
        if video_decoder_is_hardware is not None:
            self.video_decoder_is_hardware = video_decoder_is_hardware
        if video_decoder_media_type is not None:
            self.video_decoder_media_type = video_decoder_media_type
        if video_decoder_hw_accel is not None:
            self.video_decoder_hw_accel = video_decoder_hw_accel
        if video_encoder is not None:
            self.video_encoder = video_encoder
        if video_encoder_is_hardware is not None:
            self.video_encoder_is_hardware = video_encoder_is_hardware
        if video_encoder_media_type is not None:
            self.video_encoder_media_type = video_encoder_media_type
        if video_encoder_hw_accel is not None:
            self.video_encoder_hw_accel = video_encoder_hw_accel
        if video_pipeline_info is not None:
            self.video_pipeline_info = video_pipeline_info
        if subtitle_pipeline_infos is not None:
            self.subtitle_pipeline_infos = subtitle_pipeline_infos

    @property
    def audio_codec(self):
        """Gets the audio_codec of this TranscodingInfo.  # noqa: E501


        :return: The audio_codec of this TranscodingInfo.  # noqa: E501
        :rtype: str
        """
        return self._audio_codec

    @audio_codec.setter
    def audio_codec(self, audio_codec):
        """Sets the audio_codec of this TranscodingInfo.


        :param audio_codec: The audio_codec of this TranscodingInfo.  # noqa: E501
        :type: str
        """

        self._audio_codec = audio_codec

    @property
    def video_codec(self):
        """Gets the video_codec of this TranscodingInfo.  # noqa: E501


        :return: The video_codec of this TranscodingInfo.  # noqa: E501
        :rtype: str
        """
        return self._video_codec

    @video_codec.setter
    def video_codec(self, video_codec):
        """Sets the video_codec of this TranscodingInfo.


        :param video_codec: The video_codec of this TranscodingInfo.  # noqa: E501
        :type: str
        """

        self._video_codec = video_codec

    @property
    def sub_protocol(self):
        """Gets the sub_protocol of this TranscodingInfo.  # noqa: E501


        :return: The sub_protocol of this TranscodingInfo.  # noqa: E501
        :rtype: str
        """
        return self._sub_protocol

    @sub_protocol.setter
    def sub_protocol(self, sub_protocol):
        """Sets the sub_protocol of this TranscodingInfo.


        :param sub_protocol: The sub_protocol of this TranscodingInfo.  # noqa: E501
        :type: str
        """

        self._sub_protocol = sub_protocol

    @property
    def container(self):
        """Gets the container of this TranscodingInfo.  # noqa: E501


        :return: The container of this TranscodingInfo.  # noqa: E501
        :rtype: str
        """
        return self._container

    @container.setter
    def container(self, container):
        """Sets the container of this TranscodingInfo.


        :param container: The container of this TranscodingInfo.  # noqa: E501
        :type: str
        """

        self._container = container

    @property
    def is_video_direct(self):
        """Gets the is_video_direct of this TranscodingInfo.  # noqa: E501


        :return: The is_video_direct of this TranscodingInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_video_direct

    @is_video_direct.setter
    def is_video_direct(self, is_video_direct):
        """Sets the is_video_direct of this TranscodingInfo.


        :param is_video_direct: The is_video_direct of this TranscodingInfo.  # noqa: E501
        :type: bool
        """

        self._is_video_direct = is_video_direct

    @property
    def is_audio_direct(self):
        """Gets the is_audio_direct of this TranscodingInfo.  # noqa: E501


        :return: The is_audio_direct of this TranscodingInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_audio_direct

    @is_audio_direct.setter
    def is_audio_direct(self, is_audio_direct):
        """Sets the is_audio_direct of this TranscodingInfo.


        :param is_audio_direct: The is_audio_direct of this TranscodingInfo.  # noqa: E501
        :type: bool
        """

        self._is_audio_direct = is_audio_direct

    @property
    def bitrate(self):
        """Gets the bitrate of this TranscodingInfo.  # noqa: E501


        :return: The bitrate of this TranscodingInfo.  # noqa: E501
        :rtype: int
        """
        return self._bitrate

    @bitrate.setter
    def bitrate(self, bitrate):
        """Sets the bitrate of this TranscodingInfo.


        :param bitrate: The bitrate of this TranscodingInfo.  # noqa: E501
        :type: int
        """

        self._bitrate = bitrate

    @property
    def audio_bitrate(self):
        """Gets the audio_bitrate of this TranscodingInfo.  # noqa: E501


        :return: The audio_bitrate of this TranscodingInfo.  # noqa: E501
        :rtype: int
        """
        return self._audio_bitrate

    @audio_bitrate.setter
    def audio_bitrate(self, audio_bitrate):
        """Sets the audio_bitrate of this TranscodingInfo.


        :param audio_bitrate: The audio_bitrate of this TranscodingInfo.  # noqa: E501
        :type: int
        """

        self._audio_bitrate = audio_bitrate

    @property
    def video_bitrate(self):
        """Gets the video_bitrate of this TranscodingInfo.  # noqa: E501


        :return: The video_bitrate of this TranscodingInfo.  # noqa: E501
        :rtype: int
        """
        return self._video_bitrate

    @video_bitrate.setter
    def video_bitrate(self, video_bitrate):
        """Sets the video_bitrate of this TranscodingInfo.


        :param video_bitrate: The video_bitrate of this TranscodingInfo.  # noqa: E501
        :type: int
        """

        self._video_bitrate = video_bitrate

    @property
    def framerate(self):
        """Gets the framerate of this TranscodingInfo.  # noqa: E501


        :return: The framerate of this TranscodingInfo.  # noqa: E501
        :rtype: float
        """
        return self._framerate

    @framerate.setter
    def framerate(self, framerate):
        """Sets the framerate of this TranscodingInfo.


        :param framerate: The framerate of this TranscodingInfo.  # noqa: E501
        :type: float
        """

        self._framerate = framerate

    @property
    def completion_percentage(self):
        """Gets the completion_percentage of this TranscodingInfo.  # noqa: E501


        :return: The completion_percentage of this TranscodingInfo.  # noqa: E501
        :rtype: float
        """
        return self._completion_percentage

    @completion_percentage.setter
    def completion_percentage(self, completion_percentage):
        """Sets the completion_percentage of this TranscodingInfo.


        :param completion_percentage: The completion_percentage of this TranscodingInfo.  # noqa: E501
        :type: float
        """

        self._completion_percentage = completion_percentage

    @property
    def transcoding_position_ticks(self):
        """Gets the transcoding_position_ticks of this TranscodingInfo.  # noqa: E501


        :return: The transcoding_position_ticks of this TranscodingInfo.  # noqa: E501
        :rtype: float
        """
        return self._transcoding_position_ticks

    @transcoding_position_ticks.setter
    def transcoding_position_ticks(self, transcoding_position_ticks):
        """Sets the transcoding_position_ticks of this TranscodingInfo.


        :param transcoding_position_ticks: The transcoding_position_ticks of this TranscodingInfo.  # noqa: E501
        :type: float
        """

        self._transcoding_position_ticks = transcoding_position_ticks

    @property
    def transcoding_start_position_ticks(self):
        """Gets the transcoding_start_position_ticks of this TranscodingInfo.  # noqa: E501


        :return: The transcoding_start_position_ticks of this TranscodingInfo.  # noqa: E501
        :rtype: float
        """
        return self._transcoding_start_position_ticks

    @transcoding_start_position_ticks.setter
    def transcoding_start_position_ticks(self, transcoding_start_position_ticks):
        """Sets the transcoding_start_position_ticks of this TranscodingInfo.


        :param transcoding_start_position_ticks: The transcoding_start_position_ticks of this TranscodingInfo.  # noqa: E501
        :type: float
        """

        self._transcoding_start_position_ticks = transcoding_start_position_ticks

    @property
    def width(self):
        """Gets the width of this TranscodingInfo.  # noqa: E501


        :return: The width of this TranscodingInfo.  # noqa: E501
        :rtype: int
        """
        return self._width

    @width.setter
    def width(self, width):
        """Sets the width of this TranscodingInfo.


        :param width: The width of this TranscodingInfo.  # noqa: E501
        :type: int
        """

        self._width = width

    @property
    def height(self):
        """Gets the height of this TranscodingInfo.  # noqa: E501


        :return: The height of this TranscodingInfo.  # noqa: E501
        :rtype: int
        """
        return self._height

    @height.setter
    def height(self, height):
        """Sets the height of this TranscodingInfo.


        :param height: The height of this TranscodingInfo.  # noqa: E501
        :type: int
        """

        self._height = height

    @property
    def audio_channels(self):
        """Gets the audio_channels of this TranscodingInfo.  # noqa: E501


        :return: The audio_channels of this TranscodingInfo.  # noqa: E501
        :rtype: int
        """
        return self._audio_channels

    @audio_channels.setter
    def audio_channels(self, audio_channels):
        """Sets the audio_channels of this TranscodingInfo.


        :param audio_channels: The audio_channels of this TranscodingInfo.  # noqa: E501
        :type: int
        """

        self._audio_channels = audio_channels

    @property
    def transcode_reasons(self):
        """Gets the transcode_reasons of this TranscodingInfo.  # noqa: E501


        :return: The transcode_reasons of this TranscodingInfo.  # noqa: E501
        :rtype: list[TranscodeReason]
        """
        return self._transcode_reasons

    @transcode_reasons.setter
    def transcode_reasons(self, transcode_reasons):
        """Sets the transcode_reasons of this TranscodingInfo.


        :param transcode_reasons: The transcode_reasons of this TranscodingInfo.  # noqa: E501
        :type: list[TranscodeReason]
        """

        self._transcode_reasons = transcode_reasons

    @property
    def current_cpu_usage(self):
        """Gets the current_cpu_usage of this TranscodingInfo.  # noqa: E501

        Deprecated, please use ProcessStatistics instead  # noqa: E501

        :return: The current_cpu_usage of this TranscodingInfo.  # noqa: E501
        :rtype: float
        """
        return self._current_cpu_usage

    @current_cpu_usage.setter
    def current_cpu_usage(self, current_cpu_usage):
        """Sets the current_cpu_usage of this TranscodingInfo.

        Deprecated, please use ProcessStatistics instead  # noqa: E501

        :param current_cpu_usage: The current_cpu_usage of this TranscodingInfo.  # noqa: E501
        :type: float
        """

        self._current_cpu_usage = current_cpu_usage

    @property
    def average_cpu_usage(self):
        """Gets the average_cpu_usage of this TranscodingInfo.  # noqa: E501

        Deprecated, please use ProcessStatistics instead  # noqa: E501

        :return: The average_cpu_usage of this TranscodingInfo.  # noqa: E501
        :rtype: float
        """
        return self._average_cpu_usage

    @average_cpu_usage.setter
    def average_cpu_usage(self, average_cpu_usage):
        """Sets the average_cpu_usage of this TranscodingInfo.

        Deprecated, please use ProcessStatistics instead  # noqa: E501

        :param average_cpu_usage: The average_cpu_usage of this TranscodingInfo.  # noqa: E501
        :type: float
        """

        self._average_cpu_usage = average_cpu_usage

    @property
    def cpu_history(self):
        """Gets the cpu_history of this TranscodingInfo.  # noqa: E501

        Deprecated, please use ProcessStatistics instead  # noqa: E501

        :return: The cpu_history of this TranscodingInfo.  # noqa: E501
        :rtype: list[TupleDoubleDouble]
        """
        return self._cpu_history

    @cpu_history.setter
    def cpu_history(self, cpu_history):
        """Sets the cpu_history of this TranscodingInfo.

        Deprecated, please use ProcessStatistics instead  # noqa: E501

        :param cpu_history: The cpu_history of this TranscodingInfo.  # noqa: E501
        :type: list[TupleDoubleDouble]
        """

        self._cpu_history = cpu_history

    @property
    def process_statistics(self):
        """Gets the process_statistics of this TranscodingInfo.  # noqa: E501


        :return: The process_statistics of this TranscodingInfo.  # noqa: E501
        :rtype: ProcessRunMetricsProcessStatistics
        """
        return self._process_statistics

    @process_statistics.setter
    def process_statistics(self, process_statistics):
        """Sets the process_statistics of this TranscodingInfo.


        :param process_statistics: The process_statistics of this TranscodingInfo.  # noqa: E501
        :type: ProcessRunMetricsProcessStatistics
        """

        self._process_statistics = process_statistics

    @property
    def current_throttle(self):
        """Gets the current_throttle of this TranscodingInfo.  # noqa: E501


        :return: The current_throttle of this TranscodingInfo.  # noqa: E501
        :rtype: int
        """
        return self._current_throttle

    @current_throttle.setter
    def current_throttle(self, current_throttle):
        """Sets the current_throttle of this TranscodingInfo.


        :param current_throttle: The current_throttle of this TranscodingInfo.  # noqa: E501
        :type: int
        """

        self._current_throttle = current_throttle

    @property
    def video_decoder(self):
        """Gets the video_decoder of this TranscodingInfo.  # noqa: E501


        :return: The video_decoder of this TranscodingInfo.  # noqa: E501
        :rtype: str
        """
        return self._video_decoder

    @video_decoder.setter
    def video_decoder(self, video_decoder):
        """Sets the video_decoder of this TranscodingInfo.


        :param video_decoder: The video_decoder of this TranscodingInfo.  # noqa: E501
        :type: str
        """

        self._video_decoder = video_decoder

    @property
    def video_decoder_is_hardware(self):
        """Gets the video_decoder_is_hardware of this TranscodingInfo.  # noqa: E501


        :return: The video_decoder_is_hardware of this TranscodingInfo.  # noqa: E501
        :rtype: bool
        """
        return self._video_decoder_is_hardware

    @video_decoder_is_hardware.setter
    def video_decoder_is_hardware(self, video_decoder_is_hardware):
        """Sets the video_decoder_is_hardware of this TranscodingInfo.


        :param video_decoder_is_hardware: The video_decoder_is_hardware of this TranscodingInfo.  # noqa: E501
        :type: bool
        """

        self._video_decoder_is_hardware = video_decoder_is_hardware

    @property
    def video_decoder_media_type(self):
        """Gets the video_decoder_media_type of this TranscodingInfo.  # noqa: E501


        :return: The video_decoder_media_type of this TranscodingInfo.  # noqa: E501
        :rtype: str
        """
        return self._video_decoder_media_type

    @video_decoder_media_type.setter
    def video_decoder_media_type(self, video_decoder_media_type):
        """Sets the video_decoder_media_type of this TranscodingInfo.


        :param video_decoder_media_type: The video_decoder_media_type of this TranscodingInfo.  # noqa: E501
        :type: str
        """

        self._video_decoder_media_type = video_decoder_media_type

    @property
    def video_decoder_hw_accel(self):
        """Gets the video_decoder_hw_accel of this TranscodingInfo.  # noqa: E501


        :return: The video_decoder_hw_accel of this TranscodingInfo.  # noqa: E501
        :rtype: str
        """
        return self._video_decoder_hw_accel

    @video_decoder_hw_accel.setter
    def video_decoder_hw_accel(self, video_decoder_hw_accel):
        """Sets the video_decoder_hw_accel of this TranscodingInfo.


        :param video_decoder_hw_accel: The video_decoder_hw_accel of this TranscodingInfo.  # noqa: E501
        :type: str
        """

        self._video_decoder_hw_accel = video_decoder_hw_accel

    @property
    def video_encoder(self):
        """Gets the video_encoder of this TranscodingInfo.  # noqa: E501


        :return: The video_encoder of this TranscodingInfo.  # noqa: E501
        :rtype: str
        """
        return self._video_encoder

    @video_encoder.setter
    def video_encoder(self, video_encoder):
        """Sets the video_encoder of this TranscodingInfo.


        :param video_encoder: The video_encoder of this TranscodingInfo.  # noqa: E501
        :type: str
        """

        self._video_encoder = video_encoder

    @property
    def video_encoder_is_hardware(self):
        """Gets the video_encoder_is_hardware of this TranscodingInfo.  # noqa: E501


        :return: The video_encoder_is_hardware of this TranscodingInfo.  # noqa: E501
        :rtype: bool
        """
        return self._video_encoder_is_hardware

    @video_encoder_is_hardware.setter
    def video_encoder_is_hardware(self, video_encoder_is_hardware):
        """Sets the video_encoder_is_hardware of this TranscodingInfo.


        :param video_encoder_is_hardware: The video_encoder_is_hardware of this TranscodingInfo.  # noqa: E501
        :type: bool
        """

        self._video_encoder_is_hardware = video_encoder_is_hardware

    @property
    def video_encoder_media_type(self):
        """Gets the video_encoder_media_type of this TranscodingInfo.  # noqa: E501


        :return: The video_encoder_media_type of this TranscodingInfo.  # noqa: E501
        :rtype: str
        """
        return self._video_encoder_media_type

    @video_encoder_media_type.setter
    def video_encoder_media_type(self, video_encoder_media_type):
        """Sets the video_encoder_media_type of this TranscodingInfo.


        :param video_encoder_media_type: The video_encoder_media_type of this TranscodingInfo.  # noqa: E501
        :type: str
        """

        self._video_encoder_media_type = video_encoder_media_type

    @property
    def video_encoder_hw_accel(self):
        """Gets the video_encoder_hw_accel of this TranscodingInfo.  # noqa: E501


        :return: The video_encoder_hw_accel of this TranscodingInfo.  # noqa: E501
        :rtype: str
        """
        return self._video_encoder_hw_accel

    @video_encoder_hw_accel.setter
    def video_encoder_hw_accel(self, video_encoder_hw_accel):
        """Sets the video_encoder_hw_accel of this TranscodingInfo.


        :param video_encoder_hw_accel: The video_encoder_hw_accel of this TranscodingInfo.  # noqa: E501
        :type: str
        """

        self._video_encoder_hw_accel = video_encoder_hw_accel

    @property
    def video_pipeline_info(self):
        """Gets the video_pipeline_info of this TranscodingInfo.  # noqa: E501


        :return: The video_pipeline_info of this TranscodingInfo.  # noqa: E501
        :rtype: list[TranscodingVpStepInfo]
        """
        return self._video_pipeline_info

    @video_pipeline_info.setter
    def video_pipeline_info(self, video_pipeline_info):
        """Sets the video_pipeline_info of this TranscodingInfo.


        :param video_pipeline_info: The video_pipeline_info of this TranscodingInfo.  # noqa: E501
        :type: list[TranscodingVpStepInfo]
        """

        self._video_pipeline_info = video_pipeline_info

    @property
    def subtitle_pipeline_infos(self):
        """Gets the subtitle_pipeline_infos of this TranscodingInfo.  # noqa: E501


        :return: The subtitle_pipeline_infos of this TranscodingInfo.  # noqa: E501
        :rtype: list[list[TranscodingVpStepInfo]]
        """
        return self._subtitle_pipeline_infos

    @subtitle_pipeline_infos.setter
    def subtitle_pipeline_infos(self, subtitle_pipeline_infos):
        """Sets the subtitle_pipeline_infos of this TranscodingInfo.


        :param subtitle_pipeline_infos: The subtitle_pipeline_infos of this TranscodingInfo.  # noqa: E501
        :type: list[list[TranscodingVpStepInfo]]
        """

        self._subtitle_pipeline_infos = subtitle_pipeline_infos

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TranscodingInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TranscodingInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
